@@ -181,27 +181,10 @@ CEcaIAManager::slotPlay(bool bRecord)
     break;
   }
 
-  setIOToCurrentChainsetup(bRecord);
-  slotSetMasterPosition(this->nMasterPosition);
-
-  if ( !this->isValidChainsetup() ) {
-    emit finished();
+  if ( !start(bRecord) ) {
     return;
   }
 
-  killTimers(); // kill all timers
-  nTimerIDFinished   = startTimer(500); // 500-milisecond timer
-  nTimerIDCurrentPos = startTimer(100); // 100-milisecond timer
-
-  if ( bRecord ) {
-    rStatus = Recording;
-  } else {
-    rStatus = Playing;
-  }
-
-  command("cs-set-audio-format " + formatRecording.sourceFormatInString());
-  command("cs-set-param -b:" + QString("%1").arg(nBufferSize));
-  command("cs-connect");
   command("start");
 }
 
@@ -220,9 +203,16 @@ CEcaIAManager::slotStop()
 /////////////////////////////////////////////////////////////////////////////
 
 void
-CEcaIAManager::slotPause()
+CEcaIAManager::slotPause(bool bRecord)
 {
-  killTimers(); // kill all timers
+  if ( runningStatus() == NotRunning ) {
+    if ( !start(bRecord) ) {
+      return;
+    }
+  } else {
+    killTimers();
+  }
+
   command("stop");
 }
 
@@ -1003,7 +993,7 @@ CEcaIAManager::timerEvent(QTimerEvent* TimerEvent)
   if ( TimerEvent->timerId() == nTimerIDFinished ) {
     if ( engineStatus() == Finished ) { // when finished
       killTimer(nTimerIDFinished);
-      doDetailStopped();
+      slotStop();
     }
   } else if ( TimerEvent->timerId() == nTimerIDCurrentPos ) {
     emit moved(pos());
@@ -1091,6 +1081,36 @@ CEcaIAManager::doDetailStopped()
 
 /////////////////////////////////////////////////////////////////////////////
 
+bool 
+CEcaIAManager::start(bool bRecord)
+{
+  setIOToCurrentChainsetup(bRecord);
+  slotSetMasterPosition(this->nMasterPosition);
+
+  if ( !this->isValidChainsetup() ) {
+    emit finished();
+    return false;
+  }
+
+  killTimers(); // kill all timers
+  nTimerIDFinished   = startTimer(500); // 500-milisecond timer
+  nTimerIDCurrentPos = startTimer(100); // 100-milisecond timer
+
+  if ( bRecord ) {
+    rStatus = Recording;
+  } else {
+    rStatus = Playing;
+  }
+
+  command("cs-set-audio-format " + formatRecording.sourceFormatInString());
+  command("cs-set-param -b:" + QString("%1").arg(nBufferSize));
+  command("cs-connect");
+
+  return true;
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 void
 CEcaIAManager::prepareTracks(bool bIgnoresRecord)
 {
