@@ -90,6 +90,8 @@ public slots:
   //! \brief Ĺꤹ롣
   //! setMaximumWidthȤϰۤʤ롣
   void slotSetMaximumLength(int nLen);
+  //! \brief ɽʸꤹ롣
+  void slotSetText(const QString& strCaption);
 
 protected:
   void mousePressEvent(QMouseEvent* Event);
@@ -105,7 +107,7 @@ private:
     RightResizing
   };
 
-  QFrame* FrameFace;
+  QLabel* FrameFace;
   QColor  colorFace;
   QColor  colorStretcher;
   int nMaxLen;
