@@ -325,15 +325,16 @@ WVoxStorm::setupActions()
   ToggleActionRec->plug(PopupMenu);
   ToggleActionRec->plug(toolBar());
 
-  Action = new KAction(i18n("P&ause"),
+  ActionPause = new KAction(
+                       i18n("P&ause"),
                        "voxstorm_pause",
                        KShortcut(CTRL+Key_A),
                        this,
                        SLOT(slotPause()),
                        actionCollection(),
                        "Pause");
-  Action->plug(PopupMenu);
-  Action->plug(toolBar());
+  ActionPause->plug(PopupMenu);
+  ActionPause->plug(toolBar());
 
   Action = new KAction(i18n("&Stop"),
                        "voxstorm_stop",
@@ -487,7 +488,6 @@ WVoxStorm::queryClose()
 {
   if ( maybeSave() ) {
     QApplication::setOverrideCursor(waitCursor);
-    slotStop();
     if ( ToggleActionInteractive->isChecked() ) {
       ecaIAManager.slotReleaseCurrentChainsetup();
     }
@@ -665,6 +665,19 @@ WVoxStorm::setWidgetsByIAState()
 
 /////////////////////////////////////////////////////////////////////////////
 
+void 
+WVoxStorm::prepareChainsToManager()
+{
+  ecaIAManager.slotRemoveAllChains();
+  int nCount = VoxBase->getTrackCount();
+  int i;
+  for ( i = 0; i < nCount; i++ ) {
+    ecaIAManager.slotAddChain(VoxBase->getTrackInf(i));
+  }
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 QDomNode 
 WVoxStorm::stateInDOM()
 {
@@ -809,32 +822,25 @@ WVoxStorm::slotPlay()
     LabelStatusBar->setText(i18n("Playing..."));
   }
   if ( ToggleActionInteractive->isChecked() ) {
-    if ( bPause ) {  // PAUSE -> PLAY
-      ActionPlay->setEnabled(false);
-      ToggleActionRec->setEnabled(false);
-      ActionTrackOrder->setEnabled(false);
-      ActionMixdown->setEnabled(false);
-      VoxBase->slotChangeState(WVoxBase::Play);
-      VoxBase->slotChangeMessageTab(WVoxBase::Console);
+    ActionPlay->setEnabled(false);
+    ToggleActionRec->setEnabled(false);
+    ActionPause->setEnabled(true);
+    ActionTrackOrder->setEnabled(false);
+    ActionMixdown->setEnabled(false);
+    VoxBase->slotChangeState(WVoxBase::Play);
+    VoxBase->slotChangeMessageTab(WVoxBase::Console);
+
+    // PAUSE -> PLAY
+    if ( bPause ) {
       ecaIAManager.slotResume();
       bPause = false;
-    } else {         // STOP  -> PLAY
-      ecaIAManager.slotRemoveAllChains();
-      int nCount = VoxBase->getTrackCount();
-      int i;
-      for ( i = 0; i < nCount; i++ ) {
-        ecaIAManager.slotAddChain(VoxBase->getTrackInf(i));
-      }
+    }
+    // STOP -> PLAY
+    else {
+      prepareChainsToManager();
 
-      ActionPlay->setEnabled(false);
-      ToggleActionRec->setEnabled(false);
-      ActionTrackOrder->setEnabled(false);
-      ActionMixdown->setEnabled(false);
-      VoxBase->slotChangeState(WVoxBase::Play);
-      VoxBase->slotChangeMessageTab(WVoxBase::Console);
       ecaIAManager.slotPlay(ToggleActionRec->isChecked());
     }
-  } else {
   }
   QApplication::restoreOverrideCursor();
 }
@@ -853,12 +859,26 @@ void
 WVoxStorm::slotPause()
 {
   QApplication::setOverrideCursor(waitCursor);
+  LabelStatusBar->setText(i18n("Pausing..."));
   if ( ToggleActionInteractive->isChecked() ) {
-    ecaIAManager.slotPause();
+    // STOP -> PAUSE
+    if ( ecaIAManager.runningStatus() == CEcaIAManager::NotRunning ) {
+      prepareChainsToManager();
+
+      ToggleActionRec->setEnabled(false);
+      ActionTrackOrder->setEnabled(false);
+      ActionMixdown->setEnabled(false);
+      VoxBase->slotChangeState(WVoxBase::Play);
+      VoxBase->slotChangeMessageTab(WVoxBase::Console);
+    }
+    ActionPause->setEnabled(false);
     ActionPlay->setEnabled(true);
     VoxBase->slotChangeState(WVoxBase::Pause);
-    LabelStatusBar->setText(i18n("Pausing..."));
-    bPause = true;
+    ecaIAManager.slotPause(ToggleActionRec->isChecked());
+
+    if ( ecaIAManager.runningStatus() == CEcaIAManager::Playing ) {
+      bPause = true;
+    }
   }
   QApplication::restoreOverrideCursor();
 }
@@ -1211,6 +1231,7 @@ WVoxStorm::slotFinish()
   ActionForward->setEnabled(true);
   ActionRewind->setEnabled(true);
   ActionJumpToStart->setEnabled(true);
+  ActionPause->setEnabled(true);
   ToggleActionRec->setEnabled(true);
   ActionPlay->setEnabled(true);
   LabelStatusBar->setText("");
