@@ -101,6 +101,8 @@ private:
   KAction*       ActionForward;
   //! Ͽ
   KToggleAction* ToggleActionRec;
+  //! ߥ
+  KAction*       ActionPause;
   //! ȥå
   KAction*       ActionTrackOrder;
   //! ߥå󥢥
@@ -152,6 +154,11 @@ private:
   //! \brief 󥿥饯ƥ֥⡼ɤξ֤ˤäơ
   //! åȤξ֤ѹ롣
   void setWidgetsByIAState();
+  //! \brief ecaIAManagerɲäϿߤ롣
+  //!
+  //! ŤecaIAManager롣
+  //! slotPlayslotPause饳뤵롣
+  void prepareChainsToManager();
   //! \brief Vox Storm󥹥󥹤ξ֤
   //! DOMΡɤ֤
   QDomNode stateInDOM();
