@@ -26,6 +26,7 @@
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
+#include <stdlib.h>
 #include <qcursor.h>
 #include <qlayout.h>
 #include <qscrollview.h>
@@ -35,6 +36,7 @@
 #include "wvoxtrack.h"
 #include "wnamedialog.h"
 #include "wtimedialog.h"
+#include "wladspadialog.h"
 #include "cvoxstormglobal.h"
 
 /////////////////////////////////////////////////////////////////////////////
@@ -96,7 +98,7 @@ WVoxTrack::~WVoxTrack()
 
 /////////////////////////////////////////////////////////////////////////////
 
-void 
+void
 WVoxTrack::setupWidgets(const QTime& timeMaxSession)
 {
   // this has VBoxController
@@ -124,7 +126,7 @@ WVoxTrack::setupWidgets(const QTime& timeMaxSession)
   LabelLevel = new QLabel("Level (%)", VBoxValue);
 
   IntNumInputLevel = new KIntNumInput(VBoxValue);
-  IntNumInputLevel->setRange(0, 600);
+  IntNumInputLevel->setRange(0, 1600);
   IntNumInputLevel->setValue(100);  // 100 %
 
   LabelPan = new QLabel("Pan (center : 50)", VBoxValue);
@@ -166,8 +168,16 @@ WVoxTrack::setupWidgets(const QTime& timeMaxSession)
   PushButtonRec->setOn(false);
   PushButtonRec->setMaximumWidth(PushButtonRec->sizeHint().width());
 
-  HBoxTop->setMaximumWidth(350);
-  HBoxTop->setMinimumWidth(350);
+  //!!
+#if 0
+  {
+    QPushButton* Button = new QPushButton(i18n("Edit Effects..."), HBoxTop);
+    connect(Button, SIGNAL(clicked()), this, SLOT(slotEditEffects()));
+  }
+#endif
+  
+  HBoxTop->setMaximumWidth(400);
+  HBoxTop->setMinimumWidth(400);
 
   Locator = new WSoundLocator(timeMaxSession, this);
   HBoxLayout->addWidget(Locator, 100);
@@ -236,9 +246,14 @@ WVoxTrack::setupPopupMenu()
 
   PopupMenu->insertSeparator();
 
+  nMenuIDEffects = PopupMenu->insertItem(i18n("Edit Effects..."), 
+                        this, SLOT(slotEditEffects()));
+
+  PopupMenu->insertSeparator();
+
   nMenuIDProperty = PopupMenu->insertItem(
                         i18n("&View Property of This Track"), 
-			this, 
+                        this, 
                         SLOT(slotProperty()));
 }
 
@@ -788,6 +803,11 @@ WVoxTrack::slotSetLength(const QTime& time)
 void 
 WVoxTrack::slotChangedFileName(const QString& strFileName)
 {
+  // set defaults value to locator attributes
+  slotSetStartPosition(QTime());
+  slotSetOffset(QTime());
+  slotSetLength(QTime());
+
   Locator->bind(strFileName);
 }
 
@@ -895,6 +915,17 @@ WVoxTrack::slotChangeLength()
 
 /////////////////////////////////////////////////////////////////////////////
 
+void 
+WVoxTrack::slotEditEffects()
+{
+  WLadspaDialog ladspaDialog(getenv("LADSPA_PATH"), this);
+
+  if ( ladspaDialog.exec() == QDialog::Accepted ) {
+  }
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 void 
 WVoxTrack::slotProperty()
 {
